%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code provides Statistics for Forecast Performance
%----------------------------------------------------------------------------------
% written by Haoxi Yang and Arie E. Gozluklu, February 2016
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; clc; warning off
addpath('.\data;','.\Library;','.\Results;','.\Results\temp;',...
        '.\Results\est;','.\Results\estimation results;')
    
% Set global some parameters and intermediate result for global using or
% the purpose of checking.
%%       A. Data and Model Specification  

% Define path and load data
date          = xlsread('MainDataset.xls','Quarterly','A358:A577');    % 1960Q1 - 2014Q4
ydata_FB      = xlsread('MainDataset.xls','Quarterly','AF358:AJ573');  % Fama-Bliss zero Coupon Bonds 1957q2-2012q4 %(CRSP)
ydata_GSW     = xlsread('MainDataset.xls','Quarterly','AY358:BN577');  % Gurkaynak, Sack and Wright(2006), Maturity 1-15year
my            = xlsread('MainDataset.xls','Quarterly','Z358:Z600');
load LNfactor_Q.mat                % save from the code LNfactor.m
LNreal        = -LNfactor_Q(:,2); % real activity factor 
LNinf         = -LNfactor_Q(:,3); % pricing factor 

% Choose estimation smaple
beg_smpl      = find(date==19613);% Fama-Bliss: 1-5 maturity, 1960Q1
                                  % GSW: 1-7 year maturity, 1961Q3
                                  % GSW: 8-10 year maturity, 1971Q3
                                  % GSW: 11-15 year maturity,1971Q4
end_smpl      = find(date==20134);% 20134

% Yields
y3m           = ydata_GSW(beg_smpl:end_smpl,1)/400;            % per quarter
yields_GSW    = ydata_GSW(beg_smpl:end_smpl,2:end)./400;       % per quarter

% Annualized in percentage
numMat        = [1 2 3 4 5];      % number of maturities. It can be 1:1:15
yields        = [y3m yields_GSW(:,numMat)].*400;
GSWdata       = yields;



LENGTH  = round((2013+4/4 - (1961+3/4) +1/4)*4); 
START   = round((1961+3/4 - (1961+3/4) +1/4)*4); 
yield   = GSWdata(START:LENGTH, :);  % Select yields from the data sheet.

MAdata  = [LNinf(beg_smpl:end_smpl) LNreal(beg_smpl:end_smpl)]; 

my      = my(beg_smpl:end); 
%%
%macro=0; demog=0;  % Parameters to initialize
mac  = 1; 
trp  = 1; 
rest = 1;
ForecastName = [cd,'\Results\forecast\yh_CS3_ll_ma2',num2str(mac),'_f_trp',num2str(trp)];
% ForecastName_ul = [cd,'\Results\forecast\yh_CS3_ll_ma2_ul',num2str(mac),'_f_trp',num2str(trp)];
ForecastName_t = [cd,'\Results\forecast\yh_CS3_tays1_ma2',num2str(mac),'_f_trp',num2str(trp),'_rest',num2str(rest)];
load(ForecastName); % 'yhs'
%%
% % % if trp == 1
% % %     yhs = yhs(:,2:150,:);
% % % end
%%
% load(ForecastName_ul); % 'yhs_ul'
load(ForecastName_t); %'yhs_t'
%ForecastMName = [cd,'\Results\forecastM\xh_CS3_ma2',num2str(mac),'_f_trp',num2str(trp)];
ForecastMName = [cd,'\Results\forecastM\xh_CS3_ll_ma2',num2str(mac),'_f_trp',num2str(trp)];
%ForecastMName_t = [cd,'\Results\forecastM\xh_CS3_tays1_ma2',num2str(mac),'_f_trp',num2str(trp)];
ForecastMName_t = [cd,'\Results\forecastM\xh_CS3_tays1_ma2',num2str(mac),'_f_trp',num2str(trp),'_rest',num2str(rest)];
ForecastMarName_t = [cd,'\Results\forecastM\xhar_CS3_tays1_ma2',num2str(mac),'_f_trp',num2str(trp),'_rest',num2str(rest)];
load(ForecastMName); %'xhs'
load(ForecastMName_t); %'xhs_t'
load(ForecastMarName_t);%'xhars_t'

%my=xlsread('MainDataset.xls','Quarterly','Y374:Y549');
%%
rw=80; % 100; % rolling window size
%%
T=size(yield,1); % total sample size
bi=0; % burn-in some initial estimation 
H = [1 4 8 12 16 20]; % forecast horizon
FT=T-rw-H+1-bi; % number of forecasts

% Yield Forecasts
for ii=1:size(H,2)
    cumerr_ap03(:,ii)=sum((yield(rw+bi+H(ii):end,:)'-yhs(:,bi+H(ii):end-19,ii)).^2,2);
%     cumerr_ap03(:,ii)=sum((yield(rw+bi+H(ii):end,:)'-yhs(:,1+bi:end-18-H(ii),ii)).^2,2);
    rmse_ap03(:,ii) = sqrt(cumerr_ap03(:,ii)/FT(ii));
    % cumerr_ul(:,ii)=sum((yield(rw+bi+H(ii):end,:)'-yhs_ul(:,bi+H(ii):end-19,ii)).^2,2);
    % rmse_ul(:,ii) = sqrt(cumerr_ul(:,ii)/FT(ii));
    cumerr_rw(:,ii)=sum((yield(rw+bi+H(ii):end,:)'-yield(rw+bi:end-H(ii),:)').^2,2);
    rmse_rw(:,ii) = sqrt(cumerr_rw(:,ii)/FT(ii));
    cumerr_tay(:,ii)=sum((yield(rw+bi+H(ii):end,:)'-yhs_t(:,bi+H(ii):end-19,ii)).^2,2);
%     cumerr_tay(:,ii)=sum((yield(rw+bi+H(ii):end,:)'-yhs_t(:,1+bi:end-18-H(ii),ii)).^2,2);
    rmse_tay(:,ii) = sqrt(cumerr_tay(:,ii)/FT(ii));
    % out-of smaple R2
    Ros2_ap03(:,ii)=ones(size(H,2),1)-cumerr_ap03(:,ii)./cumerr_rw(:,ii);
    % Ros2_ul(:,ii)=ones(size(H,2),1)-cumerr_ul(:,ii)./cumerr_rw(:,ii);
    Ros2_tay(:,ii)=ones(size(H,2),1)-cumerr_tay(:,ii)./cumerr_rw(:,ii);
    
    %% plot
    subplot(size(H,2)/2,2,ii); plot(yield(rw+bi+H(ii):end,6));hold on
    plot(yhs(6,bi+H(ii):end-19,ii)','g');plot(yhs_t(6,bi+H(ii):end-19,ii)','r');
    
    
    % % % %Diebold-Mariano(DM)
    % % % e2t_rw(:,ii)=(yield(rw+bi+H(ii):end,:)'-yield(rw+bi:end-H(ii),:)').^2;
    % % % e2t_ap03(:,ii)=((yield(rw+bi+H(ii):end,:)'-yhs(:,bi+H(ii):end-19,ii)).^2;
    % % % e2t_tay(:,ii)=(yield(rw+bi+H(ii):end,:)'-yhs_t(:,bi+H(ii):end-19,ii)).^2;
    % % %
    % % % dt_ap03(:,ii)=e2t_ap03(:,ii)-e2t_rw(:,ii);
    % % % dt_tay(:,ii)=e2t_tay(:,ii)-e2t_rw(:,ii);
    % % % dt_ap03_bar(:,ii)=sum(dt_ap03(:,ii));
    % % % dt_tay_bar(:,ii)=sum(dt_tay(:,ii));
end



% Macro Forecasts
% % % for ii=1:size(H,2)
% % %     cumerr_ap03_m(:,ii)=sum((MAdata(rw+bi+H(ii):end,:)'-xhs(:,bi+H(ii):end-19,ii)).^2,2);
% % %     rmse_ap03_m(:,ii) = sqrt(cumerr_ap03_m(:,ii)/FT(ii));
% % %     cumerr_ar1_m(:,ii)=sum((MAdata(rw+bi+H(ii):end,:)'-xhars_t(:,bi+H(ii):end-19,ii)).^2,2);
% % %     rmse_ar1_m(:,ii) = sqrt(cumerr_ar1_m(:,ii)/FT(ii));
% % %     cumerr_tay_m(:,ii)=sum((MAdata(rw+bi+H(ii):end,:)'-xhs_t(:,bi+H(ii):end-19,ii)).^2,2);
% % %     rmse_tay_m(:,ii) = sqrt(cumerr_tay_m(:,ii)/FT(ii));
% % % end

% Yield Forecast
% rwraRMSE_ap03 = rmse_ap03./rmse_rw
rwraRMSE_tay = rmse_tay(:,2:end)./rmse_rw(:,2:end)
% rwraRMSE_ul= rmse_ul./rmse_rw
rwraRMSE_comp= rmse_tay(:,2:end)./rmse_ap03(:,2:end)

%% Giacomini & White Test for yield forecast (mean squared error)

% Compared with Random-Walk
teststat1 = zeros(size(H,2),size(H,2));
critval1 = zeros(size(H,2),size(H,2));
pval1 = zeros(size(H,2),size(H,2));
for j = 1:size(H,2)
    tau = H(j);
    for ii=1:size(H,2)
        loss_rw = (yield(rw+bi+H(j):end,ii)'-yield(rw+bi:end-H(j),ii)').^2;
        loss_tay = (yield(rw+bi+H(j):end,ii)'-yhs_t(ii,bi+H(j):end-19,ii)).^2;
        lossdiff = (loss_rw-loss_tay)';
        instruments = [ones(size(lossdiff,1),1) lossdiff];
        [teststat1(ii,j),critval1(ii,j),pval1(ii,j)] = CPAtest(lossdiff,instruments,tau);
    end
end
pval1(:,2:end)

% Compared with Yield-Macro Model
teststat2 = zeros(size(H,2),size(H,2));
critval2 = zeros(size(H,2),size(H,2));
pval2 = zeros(size(H,2),size(H,2));
for j = 1:size(H,2)
    tau = H(j);
    for ii=1:size(H,2)
        loss_ap03 = (yield(rw+bi+H(j):end,ii)'-yhs(ii,bi+H(j):end-19,ii)).^2;
        loss_tay = (yield(rw+bi+H(j):end,ii)'-yhs_t(ii,bi+H(j):end-19,ii)).^2;
        lossdiff = (loss_ap03-loss_tay)';
        instruments = [ones(size(lossdiff,1),1) lossdiff];
        [teststat2(ii,j),critval2(ii,j),pval2(ii,j)] = CPAtest(lossdiff,instruments,tau);
    end
end
pval2(:,2:end)

% Compared with Yield-Macro Model with unit root level
% % % % % % teststat3 = zeros(size(H,2),size(H,2));
% % % % % % critval3 = zeros(size(H,2),size(H,2));
% % % % % % pval3 = zeros(size(H,2),size(H,2));
% % % % % % for j = 1:size(H,2)
% % % % % %     tau = H(j);
% % % % % %     for ii=1:size(H,2)
% % % % % %         loss_ul = (yield(rw+bi+H(j):end,ii)'-yhs_ul(ii,bi+H(j):end-19,ii)).^2;
% % % % % %         loss_tay = (yield(rw+bi+H(j):end,ii)'-yhs_t(ii,bi+H(j):end-19,ii)).^2;
% % % % % %         lossdiff = (loss_ul-loss_tay)';
% % % % % %         instruments = [ones(size(lossdiff,1),1) lossdiff];
% % % % % %         [teststat3(ii,j),critval3(ii,j),pval3(ii,j)] = CPAtest(lossdiff,instruments,tau);
% % % % % %     end
% % % % % % end

%% Clark-West test [comparision with random walk, adjusted p-value]
date_adj(:,1) = floor(date(beg_smpl:end_smpl)/10);
date_adj(:,2) = date(beg_smpl:end_smpl)-date_adj(:,1)*10;
yhs_t             =[NaN(6,rw+1,6) yhs_t];
yhs                =[NaN(6,rw+1,6) yhs];              
for hh = 1:size(H,2)
    for ii = 1:size(yield,2)
        [mspe_rw(ii,hh),mspeadj_rw(ii,hh),pvaladj_rw(ii,hh),statistics_rw(ii,hh)] = mspecw(yield(:,ii),yhs_t(ii,1:end-20,hh)',H(hh),1984+H(hh)/4,date_adj);
        [mspe_comp(ii,hh),mspeadj_comp(ii,hh),pvaladj_comp(ii,hh),statistics_comp(ii,hh)] = mspecw_general(yield(:,ii),yhs(ii,1:end-20,hh)',yhs_t(ii,1:end-20,hh)',H(hh),1984+H(hh)/4,date_adj);
    end
end
statistics_rw(:,2:end)
pvaladj_rw(:,2:end)

statistics_comp(:,2:end)
pvaladj_comp(:,2:end)