%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code provides Statistics for Forecast Usefulness
% Applying Carriero and Giacomini Lambda (2011, JoE)
%----------------------------------------------------------------------------------
% written by Haoxi Yang and Arie E. Gozluklu, Aug 2014
clear all; close all;
clc;
addpath('.\data;','.\Library;','.\Results\forecast;')

% Yield Sample: 1961Q3- 2013Q4  
date          = xlsread('MainDataset.xls','Quarterly','A364:A573');    % 1960Q1 - 2013Q4
ydata_GSW     = xlsread('MainDataset.xls','Quarterly','AY364:BN573');  % Gurkaynak, Sack and Wright(2006), Maturity 1-15year

% % % Time-varying risk premium
load yh_CS3_ll_ma21_f_trp1.mat   % load Macro model forecasts (Restricted)
load yh_CS3_tays1_ma21_f_trp1_rest1.mat % load Demographic model forecasts (Unrestricted)

% % % % Constant risk premium
% load yh_CS3_ll_ma21_f_trp0.mat   % load Macro model forecasts (Restricted)
% load yh_CS3_tays1_ma21_f_trp0_rest1.mat % load Demographic model forecasts (Unrestricted)

% Choose estimation smaple
beg_smpl      = find(date==19613);% Fama-Bliss GSW: 1-7 year maturity, 1961Q3, GSW: 8-10 year maturity, 1971Q3, % GSW: 11-15 year maturity,1971Q4
end_smpl      = find(date==20134);% 20134

H= [4 8 12 16 20]; % forecast horizon in quarters

ii=1; % for ii=1:6 % 3m-5y yield forecasts
jj=2; % for jj=1:5 % forecast horizon

alpha=0.01;

T= end_smpl-beg_smpl+1; % total sample size
m= 80; % in-sample size
n= T-m-H(jj)+1; % number of out of sample forecasts
d= 35;% CG smoothing window size, if d=1 full sample lambda 
lf= T-m; % index of last forecast, i.e. 2013Q4

% Yields
y3m           = ydata_GSW(beg_smpl:end_smpl,1)/400;            % per quarter
yields_GSW    = ydata_GSW(beg_smpl:end_smpl,2:end)./400;       % per quarter

% Annualized in percentage
numMat        = [1 2 3 4 5];      % number of maturities. It can be 1:1:15
%yields        = [y3m yields_GSW(:,numMat)].*400;
yields        = [y3m yields_GSW(:,numMat)]*4;
GSWdata       = yields;

lambda_d = zeros(T-H(jj)-m-d+2,1);

yhs=[zeros(6,m,6) yhs]; % same size as yields
yhs_t=[zeros(6,m,6) yhs_t];

% %**************************************************************************
% %%Global Usefulness (Quadratic Loss function)
y1= GSWdata(m+H(jj):T,ii)-((yhs_t(ii,m+H(jj):T,jj+1))./100)'; 
x1= [ones(size(GSWdata(m+H(jj):T,ii),1),1) GSWdata(m:T-H(jj),ii)-(yhs_t(ii,m+H(jj):T,jj+1)')./100];
 
 [beta,beta_se,R2,R2adj,varcov,F_stat]=olsgmm(y1,x1,2*(H(jj)-1),1); %NW        
 lambda_hat=beta(2)      
t_res= beta(2)/beta_se(2)
t_unres=(beta(2)-1)/beta_se(2)
t_equal=(beta(2)-0.5)/beta_se(2);

pd = makedist('Normal');
c_stn = icdf(pd,1-alpha/2);
c_stne = icdf(pd,1-alpha);

if  abs(t_res)> c_stn
    reject0=1
else 
    reject0=0
end

if  abs(t_unres)> c_stn
    reject1=1
else 
    reject1=0
end
%%Equal weight of two different specifications
if  abs(t_equal)> c_stne
    reject1=1
else 
    reject1=0
end
% %************************************************************** 
% % Time-varying Usefulness
%     for tt=1:size(lambda_d,1)         
%     beta= regress(GSWdata(m+H(jj)+tt-1:m+H(jj)+d+tt-2,ii)-(yhs_t(ii,m+H(jj)+tt-1:m+H(jj)+d+tt-2,jj+1)./100)',...
%             [ones(d,1) (GSWdata(m+tt-1:m+d+tt-2,ii)-(yhs_t(ii,m+H(jj)+tt-1:m+H(jj)+d+tt-2,jj+1)./100)')]);
%         
%         lambda_d(tt)= beta(2);
%     end
% 
% plot(lambda_d(:));
% ****************************************************************************
% Portfolio Utility Loss
tau= [1 2 3 4 5]; % Bond maturity, note first column 3 month, 
% hence tau+1 column in GWSdata
an=4; % an=8, 2-year holding period
% holding returns
if H(jj)==an % one-year holding period, jj=1
    x_th=zeros(T,an);
    for ii=1:T-H(jj)
        for pp=1:an
            x_th(ii+H(jj),pp)= -pp*GSWdata(ii+H(jj),tau(pp)+1)+(pp+1)*GSWdata(ii,tau(pp)+2)-GSWdata(ii,1);% excess returns
        end
    end
elseif H(jj)==8 % two- year holding period, jj=2
    x_th=zeros(T,an-1);
    for ii=1:T-H(jj)
        for pp=1:an-1
           x_th(ii+H(jj),pp)= (-pp*GSWdata(ii+H(jj),tau(pp)+1)+(pp+2)*GSWdata(ii,tau(pp)+3)-GSWdata(ii,1))/2; % excess returns
        end
    end
else
   x_th=zeros(T,an-2);
    for ii=1:T-H(jj)
        for pp=1:an-2
           x_th(ii+H(jj),pp)= (-pp*GSWdata(ii+H(jj),tau(pp)+1)+(pp+3)*GSWdata(ii,tau(pp)+4)-GSWdata(ii,1))/3; % excess returns
        end
    end 
end

%plot(x_th)
% forecasted returns
if H(jj)==an % one-year holding period, jj=1
    f_unres=zeros(T,an);
    f_res=zeros(T,an); % random walk forecast zero returns
    for ij=1:T-H(jj)
        for pp=1:an
            %f_unres(ij+H(jj),pp)= -pp*(yhs(pp+1,ij+H(jj),jj+1)')./100+(pp+1)*GSWdata(ij,tau(pp)+2)-GSWdata(ij,1);  % Macro 
            f_unres(ij+H(jj),pp)=-pp*(yhs_t(pp+1,ij+H(jj),jj+1)')./100+(pp+1)*GSWdata(ij,tau(pp)+2)-GSWdata(ij,1);% Demo
            f_res(ij+H(jj),pp)= -pp*GSWdata(ij,tau(pp)+1)+(pp+1)*GSWdata(ij,tau(pp)+2)-GSWdata(ij,1);% RW
        end
    end
onevec=ones(an,1);
elseif H(jj)==8 % two- year holding period, jj=2
    f_unres=zeros(T,an-1);
    f_res=zeros(T,an-1);
    for ij=1:T-H(jj)
        for pp=1:an-1
        % f_unres(ij+H(jj),pp)= (-pp*(yhs(pp+1,ij+H(jj),jj+1)')./100+(pp+2)*GSWdata(ij,tau(pp)+3)-GSWdata(ij,1))/2; % Macro 
          f_unres(ij+H(jj),pp)=  (-pp*(yhs_t(pp+1,ij+H(jj),jj+1)')./100+(pp+2)*GSWdata(ij,tau(pp)+3)-GSWdata(ij,1))/2; %Demo
          f_res(ij+H(jj),pp)= (-pp*GSWdata(ij,tau(pp)+1)+(pp+2)*GSWdata(ij,tau(pp)+3)-GSWdata(ij,1))/2; % RW
        end
    end
onevec=ones(an-1,1); 
else
    f_unres=zeros(T,an-2);
    f_res=zeros(T,an-2);
    for ij=1:T-H(jj)
        for pp=1:an-2
        % f_unres(ij+H(jj),pp)= (-pp*(yhs(pp+1,ij+H(jj),jj+1)')./100+(pp+2)*GSWdata(ij,tau(pp)+3)-GSWdata(ij,1))/2; % Macro 
          f_unres(ij+H(jj),pp)= (-pp*(yhs_t(pp+1,ij+H(jj),jj+1)')./100+(pp+3)*GSWdata(ij,tau(pp)+4)-GSWdata(ij,1))/3; % Demo
          f_res(ij+H(jj),pp)= (-pp*GSWdata(ij,tau(pp)+1)+(pp+3)*GSWdata(ij,tau(pp)+4)-GSWdata(ij,1))/2; % RW
        end
    end
onevec=ones(an-2,1);
end

gamma=0.5; % as suggested in the paper
lambda_util=0;nom=0; denom=0;
for tt=m:T-H(jj)
    sigma_hat= cov(x_th(tt-m+H(jj)+1:tt,:));
    B_hat=(1/gamma)*(inv(sigma_hat)-(inv(sigma_hat)*onevec*onevec'*inv(sigma_hat))/(onevec'*inv(sigma_hat)*onevec));
    a_hat=(inv(sigma_hat)*onevec)/(onevec'*inv(sigma_hat)*onevec);
    
    nom= nom+ (f_res(tt+H(jj),:)-f_unres(tt+H(jj),:))*B_hat'*(x_th(tt+H(jj),:)'-gamma*sigma_hat*(a_hat+B_hat*f_unres(tt+H(jj),:)'));
    denom= denom+ gamma* (f_res(tt+H(jj),:)-f_unres(tt+H(jj),:))*B_hat'*sigma_hat*B_hat*(f_res(tt+H(jj),:)-f_unres(tt+H(jj),:))';            
end
lambda_util=nom/denom

%*****************************************************************************
% Proposition 1
band= 2*(H(jj)-1);
innersum=0; omega_hat=0;
for bb=-band+1:band-1
    for kk=m+abs(bb):T-H(jj)
        sigma_hat= cov(x_th(kk-m+1:kk,:));
        B_hat=(1/gamma)*(inv(sigma_hat)-(inv(sigma_hat)*onevec*onevec'*inv(sigma_hat))/(onevec'*inv(sigma_hat)*onevec));
        a_hat=(inv(sigma_hat)*onevec)/(onevec'*inv(sigma_hat)*onevec);
        st_hat= (f_res(kk+H(jj),:)-f_unres(kk+H(jj),:))*B_hat'*(x_th(kk+H(jj),:)'-gamma*sigma_hat*...
                (a_hat+B_hat*(f_res(kk+H(jj),:)'+(1-lambda_util)*(f_unres(kk+H(jj),:)'-f_res(kk+H(jj),:)'))));
        sj_hat= (f_res(kk+H(jj)-abs(bb),:)-f_unres(kk+H(jj)-abs(bb),:))*B_hat'*(x_th(kk+H(jj)-abs(bb),:)'-gamma*sigma_hat*...
               (a_hat+B_hat*(f_res(kk+H(jj)-abs(bb),:)'+(1-lambda_util)*(f_unres(kk+H(jj)-abs(bb),:)'-f_res(kk+H(jj)-abs(bb),:)'))));
        st_sder= gamma*(f_res(kk+H(jj),:)-f_unres(kk+H(jj),:))*B_hat'*sigma_hat*B_hat*(f_res(kk+H(jj),:)-f_unres(kk+H(jj),:))';
        innersum = innersum + st_hat*sj_hat;          
    end
    omega_hat=omega_hat+(1-abs(bb/band))*innersum/n;
end

ssigma_hat=sqrt(inv(st_sder)*omega_hat*inv(st_sder)); % equatuon 6

t_res_util= sqrt(n)*lambda_util/ssigma_hat
t_unres_util=sqrt(n)*(lambda_util-1)/ssigma_hat
t_equal_util=sqrt(n)*(lambda_util-0.5)/ssigma_hat

pd = makedist('Normal');
c_stn = icdf(pd,1-alpha/2);
c_stne = icdf(pd,1-alpha);

if  abs(t_res_util)> c_stn
    reject0_util=1
else 
    reject0_util=0
end

if  abs(t_unres_util)> c_stn
    reject1_util=1
else 
    reject1_util=0
end



