%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Demographics and the real rate behaviour
%
% for the paper "Demography and the Behavior of Interest rates"
% Carlo A. Favero, Arie E. Gozluklu and Haoxi Yang(2011)
% 
% Haoxi Yang 
% @ April, 2015
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc; close all; clear all; 
addpath('.\data;','.\Library;')
load RepRealRate.mat

cstr=cal(1961,3,4,255); 
ss = ical(1961,3,cstr);       % sample size
se = ical(2013,4,cstr);

yields   = GSWdata(ss:se,:);  % zero-coupon yields with maturity 3m, 1y-5-y


Infl_ann = Infl_ann(4:end); 
date_Infl= date_Infl(4:end);

%% compute expected inflation
% assum annulized Inlfation follows AR(1) process
Infl= zeros(size(GSWdata,1)+4,5);

for ii = 1:size(GSWdata,1)+4
    lhv = Infl_ann(5:52+ii-1); rhv = [ones(size(lhv)) Infl_ann(1:48+ii-1)];
    [bv,sebv,R2v,R2vadj,v,F] = olsgmm(lhv,rhv,1,1); 
    for kk = 1:5
        drift = 0;
        for jj = 1:kk
            drift = drift + bv(1)*bv(2)^(jj-1);
            Infl_f(jj) = bv(2)^jj*lhv(end)+drift;
        end
        Infl(ii,kk) = mean(Infl_f);
    end
end

Infl_3m = 400*((1+Infl(:,1)./100).^(1/4)-1);
% plot([Infl_3m Infl(:,end)])

% start from 1961Q3
Infl = Infl(5:end-4,:);
Infl_3m = Infl_3m(5:end-4,1);

%% compute 5-year maturity real rate (yields)
yields_real = yields - [Infl_3m Infl];
% plot([yields(:,end) y5_real Infl_5e])

% compare with real long yield used in Bekaert and Engstrom using Ang, Bekaert and Wei(JF 2008)
load RepBE.mat
begBE = find(date==19684);
endBE = find(date==20074);
corr(yields_real(begBE:endBE,end),abwf)

%% Plot
T   = 1961+3*(1/4):1/4:2013+4*(1/4);

figure
[AX,H1,H2] = plotyy(T,yields_real(:,1),T,ones(size(yields,1),1)./my(1:size(yields,1)),'plot'); hold on
set(H1,'LineWidth',3,'Color','k')
set(H2,'LineStyle','--','LineWidth',3,'Color',[0.5 0.5 0.5])
set(get(AX(1),'Ylabel'),'String','simulated 3-month real yield') 
set(get(AX(2),'Ylabel'),'String','inverted Middle-Young ratio') 
set(AX(1),'YLim',[-4 12])
set(AX(2),'YLim',[0.5 2])
set(AX,'xlim',[1961.75,2015]);
xlabel('Time')
clear AX H1 H2
legend('simulated 3-month real yield','inverted Middle-Young ratio',1)
area([2008.75 2014.5], [12 12]);hold on
area([2008.75 2014.5], [-4 -4]);hold on
[AX,H1,H2] = plotyy(T,yields_real(:,1),T,ones(size(yields,1),1)./my(1:size(yields,1)),'plot');
set(H1,'LineWidth',3,'Color','k')
set(H2,'LineStyle','--','LineWidth',3,'Color',[0.5 0.5 0.5])
set(get(AX(1),'Ylabel'),'String','simulated 3-month real yield') 
set(get(AX(2),'Ylabel'),'String','inverted Middle-Young ratio') 
set(AX(1),'YLim',[-4 12])
set(AX(2),'YLim',[0.5 2])
set(AX,'xlim',[1961.75,2015]);
xlabel('Time')
clear AX H1 H2

figure
[AX,H1,H2] = plotyy(T,yields_real(:,end),T,ones(size(yields,1),1)./my(1:size(yields,1)),'plot'); hold on
set(H1,'LineWidth',3,'Color','k')
set(H2,'LineStyle','--','LineWidth',3,'Color',[0.5 0.5 0.5])
set(get(AX(1),'Ylabel'),'String','simulated 5-year real yield') 
set(get(AX(2),'Ylabel'),'String','inverted Middle-Young ratio') 
set(AX(1),'YLim',[-2 12])
set(AX(2),'YLim',[0.5 2.2])
set(AX,'xlim',[1961.75,2015]);
xlabel('Time')
legend('simulated 5-year real yield','inverted Middle-Young ratio',1)
area([2008.75 2014.5], [12 12]);hold on
area([2008.75 2014.5], [-2 -2]);hold on
[AX,H1,H2] = plotyy(T,yields_real(:,end),T,ones(size(yields,1),1)./my(1:size(yields,1)),'plot');
set(H1,'LineWidth',3,'Color','k')
set(H2,'LineStyle','--','LineWidth',3,'Color',[0.5 0.5 0.5])
set(get(AX(1),'Ylabel'),'String','simulated 5-year real yield') 
set(get(AX(2),'Ylabel'),'String','inverted Middle-Young ratio') 
set(AX(1),'YLim',[-2 12])
set(AX(2),'YLim',[0.5 2.2])
set(AX,'xlim',[1961.75,2015]);
xlabel('Time')
clear AX H1 H2

% pd ratio
figure
[AX,H1,H2] = plotyy(T,dp,T,ones(size(yields,1),1)./my(1:size(yields,1)),'plot'); hold on
set(H1,'LineWidth',3,'Color','k')
set(H2,'LineStyle','--','LineWidth',3,'Color',[0.5 0.5 0.5])
set(get(AX(1),'Ylabel'),'String','simulated 5-year real yield') 
set(get(AX(2),'Ylabel'),'String','inverted Middle-Young ratio') 
set(AX(1),'YLim',[-4.8 -2.1])
set(AX(2),'YLim',[0.1 2.2])
set(AX,'xlim',[1961.75,2015]);
xlabel('Time')
legend('log Dividend-Price ratio','inverted Middle-Young ratio',1)
area([2008.75 2014.5], [0 0]);hold on
area([2008.75 2014.5], [-5 -5]);hold on
[AX,H1,H2] = plotyy(T,dp,T,ones(size(yields,1),1)./my(1:size(yields,1)),'plot');
set(H1,'LineWidth',3,'Color','k')
set(H2,'LineStyle','--','LineWidth',3,'Color',[0.5 0.5 0.5])
set(get(AX(1),'Ylabel'),'String','log Dividend-Price ratio') 
set(get(AX(2),'Ylabel'),'String','inverted Middle-Young ratio') 
set(AX(1),'YLim',[-4.8 -2.1])
set(AX(2),'YLim',[0.1 2.2])
set(AX,'xlim',[1961.75,2015]);
xlabel('Time')
clear AX H1 H2


%% Plot Figure 7
load robustness.mat
figure
stem(tstat(:,1),'MarkerSize',3,'ShowBaseLine','off'); hold on
plot(tstat(:,2),'-r','LineWidth',3.5);
legend('simulated t-stat on MY','estimated t-stat on MY')

count = 0;
for ii = 1:size(tstat,1)
    if tstat(ii,1)< tstat(ii,2)
        count = count + 1;
    end
end
p_value = count/ii 

figure
stem(tstat_real(:,1),'MarkerSize',3,'ShowBaseLine','off'); hold on
plot(tstat_real(:,2),'-r','LineWidth',3.5);
legend('simulated t-stat on MY','estimated t-stat on MY')
count = 0;
for ii = 1:size(tstat_real,1)
    if tstat_real(ii,1)< tstat_real(ii,2)
        count = count + 1;
    end
end
p_value_real = count/ii 
