%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Demographics and permenant component of spot rate (Based on Fama (2006))
% Quarterly Data Comparison
% for the paper "Demography and the Behavior of Interest rates"
% Carlo A. Favero, Arie E. Gozluklu and Haoxi Yang(2011)
% @ September, 2011
% This code generates the results of Table_1_a in the paper with monthly data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc; close all; 
clear all; warning off
addpath('.\Library','.\data')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Read Data Series (1952m6-2008m12)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% collect the annual yields, form prices, forwards, hpr
% yields(t), forwards(t) are yields, forwards at time t
%% Initialization 
date          = xlsread('MainDataset.xls','Quarterly','A358:A577');    % 1960Q1 - 2014Q4
Time          = 1961+3/4:1/4:2013+4*(1/4);
TB3MS         = xlsread('MainDataset.xls','Quarterly','AY358:AY577');  % 3-month Tbill annulized yield, from Fred St. Louis   
ydata_FB      = xlsread('MainDataset.xls','Quarterly','AF358:AJ577');  % Fama-Bliss zero Coupon Bonds 1957q2-2012q4 %(CRSP)
ydata_GSW     = xlsread('MainDataset.xls','Quarterly','AY358:BN577');  % Gurkaynak, Sack and Wright(2006), Maturity 1-15year
my            = xlsread('MainDataset.xls','Quarterly','Z358:Z600');
cpi_core      = xlsread('MainDataset.xls','Quarterly','AU358:AU577');  % cpi index less food & energy quarterly
inf_core      = (cpi_core-lag(cpi_core,4))./lag(cpi_core,4);           % anuallized inflation
load LNfactor_Q.mat                % save from the code LNfactor.m
LNreal        = -LNfactor_Q(:,2); % real activity factor 
LNinf         = -LNfactor_Q(:,3); % pricing factor 

% Choose estimation smaple
beg_smpl      = find(date==19613);% Fama-Bliss: 1-5 maturity, 1960Q1
                                  % GSW: 1-7 year maturity, 1961Q3
                                  % GSW: 8-10 year maturity, 1971Q3
                                  % GSW: 11-15 year maturity,1971Q4
end_smpl      = find(date==20134);% 20134

% Yields
y3m           = ydata_GSW(beg_smpl:end_smpl,1)/400;            % per quarter
yields_GSW    = ydata_GSW(beg_smpl:end_smpl,2:end)./400;           % per quarter

% Annualized in percentagenumMat        = [1 2 3 4 5];      % number of maturities. It can be 1:1:15
numMat        = [1 2 3 4 5];
yields        = [y3m yields_GSW(:,numMat)].*4;
GSWdata       = yields;
inf_core      = inf_core(beg_smpl:end_smpl,1);


% Foward rates
prices   =-(ones(size(yields,1),1)*numMat).*yields(:,2:end); % log prices
forward  = prices(:,1:4)-prices(:,2:5); % forwards only for y2,..y5
fs       = forward -yields(:,2)*ones(1,4);   % forward spread over y1

my_r     = my(beg_smpl:end_smpl,1);

T        = size(yields,1); % number of yields

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Create D(t), dummy suggested by Fama(2006)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
dum=zeros(size(date));
for ii=1:size(date,1)
    if date(ii)<=19812
    dum(ii)=1;
    end
end
dum = dum(beg_smpl:end_smpl,1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Persistent Component (K(t)), 5-year rolling window __Fama trend
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
mawin=20;
K_t = zeros(size(yields,1),1);
for ii=1:size(yields,1)-mawin
K_t(ii+mawin,1)= mean(yields(ii:ii+mawin,2));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% one-year moving average MY trend 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for i=1:size(yields,1)-3
my_ma(i+3,1) = mean(my_r(i:i+3));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Persistent Component, 10-year discounted MA of last ten years of core CPI
% Cieslak&Povala trend (CP trend)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tao(1,1)=inf_core(1,1);
v=0.96; % quarterly
for i = 1:size(inf_core,1)-1
    tao(i+1,1) =  tao(i)+(1-v)*(inf_core(i+1)-tao(i));
end
tao_r = tao(end-size(my_ma,1)+1:end,1);
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TABLE 5 in paper
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
beg = 1;
%--------------------------------------------------------------------------
%Two-year change in spot rate
del=8;
Ts   = T-beg-del+1;
xy2_noc=[ones(Ts,1) dum(beg:T-del) 100*fs(1:beg+Ts-1,2)];
xy2_nod=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100];
xy2_fama=[ones(Ts,1) dum(beg:T-del) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100];
xy2_my=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) yields(beg:beg+Ts-1,1)*100 -my_ma(1:Ts,1)*100];
% xy2_cp=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) yields(beg:beg+Ts-1,1)*100 tao_r(1:1+Ts-1,1)*100];
xy2_cp=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-tao_r(1:1+Ts-1,1))*100];
xy2_all=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100 (yields(beg:beg+Ts-1,1)-tao_r(1:1+Ts-1,1))*100 yields(beg:beg+Ts-1,1)*100-my_ma(1:Ts,1)*100 ];
dy2=(yields(beg+del:T,1)-yields(beg:beg+Ts-1,1))*100;

result_2_noc = ols (dy2,xy2_noc);
result_2_nod = ols (dy2,xy2_nod);
result_2_fama = ols (dy2,xy2_fama);
result_2_cp = ols (dy2,xy2_cp);
result_2_my = ols (dy2,xy2_my);
result_2_all = ols(dy2,xy2_all);

% print resutl
disp ('x=2')
disp ('no cycle')
disp ([result_2_noc.beta result_2_noc.bstd])
disp (result_2_noc.rbar)

disp ('no dymmy')
disp ([result_2_nod.beta result_2_nod.bstd])
disp (result_2_nod.rbar)

disp ('Fama cycle')
disp ([result_2_fama.beta result_2_fama.bstd])
disp (result_2_fama.rbar)

disp ('CP cycle')
disp ([result_2_cp.beta result_2_cp.bstd])
disp (result_2_cp.rbar)

disp ('my cycle')
disp ([result_2_my.beta result_2_my.bstd])
disp (result_2_my.rbar)

disp ('all')
disp ([result_2_all.beta result_2_all.bstd])
disp (result_2_all.rbar)
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%Three-year change in spot rate
del=12;
Ts   = T-beg-del+1;
xy3_noc=[ones(Ts,1) dum(beg:T-del) 100*fs(beg:beg+Ts-1,2)];
xy3_nod=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100];
xy3_fama=[ones(Ts,1) dum(beg:T-del) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100];
xy3_my=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) yields(beg:beg+Ts-1,1)*100 -my_ma(1:Ts,1)*100];
% xy3_cp=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) yields(beg:beg+Ts-1,1)*100 tao_r(1:1+Ts-1,1)*100];
xy3_cp=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-tao_r(1:1+Ts-1,1))*100];
xy3_all=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100 (yields(beg:beg+Ts-1,1)-tao_r(1:1+Ts-1,1))*100 yields(beg:beg+Ts-1,1)*100-my_ma(1:Ts,1)*100 ];
dy3=(yields(beg+del:T,1)-yields(beg:beg+Ts-1,1))*100;

result_3_noc = ols (dy3,xy3_noc);
result_3_nod = ols (dy3,xy3_nod);
result_3_fama = ols (dy3,xy3_fama);
result_3_cp = ols (dy3,xy3_cp);
result_3_my = ols (dy3,xy3_my);
result_3_all = ols(dy2,xy2_all);

% print resutl
disp ('x=3')
disp ('no cycle')
disp ([result_3_noc.beta result_3_noc.bstd])
disp (result_3_noc.rbar)

disp ('no dymmy')
disp ([result_3_nod.beta result_3_nod.bstd])
disp (result_3_nod.rbar)

disp ('Fama cycle')
disp ([result_3_fama.beta result_3_fama.bstd])
disp (result_3_fama.rbar)

disp ('CP cycle')
disp ([result_3_cp.beta result_3_cp.bstd])
disp (result_3_cp.rbar)

disp ('my cycle')
disp ([result_3_my.beta result_3_my.bstd])
disp (result_3_my.rbar)

disp ('all')
disp ([result_3_all.beta result_3_all.bstd])
disp (result_3_all.rbar)
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%Four-year change in spot rate
del=16;
Ts   = T-beg-del+1;
xy4_noc=[ones(Ts,1) dum(beg:T-del) 100*fs(beg:beg+Ts-1,2)];
xy4_nod=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100];
xy4_fama=[ones(Ts,1) dum(beg:T-del) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100];
xy4_my=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) yields(beg:beg+Ts-1,1)*100 -my_ma(1:Ts,1)*100];
% xy4_cp=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) yields(beg:beg+Ts-1,1)*100 tao_r(1:1+Ts-1,1)*100];
xy4_cp=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-tao_r(1:1+Ts-1,1))*100];
xy4_all=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100 (yields(beg:beg+Ts-1,1)-tao_r(1:1+Ts-1,1))*100 yields(beg:beg+Ts-1,1)*100-my_ma(1:Ts,1)*100 ];
dy4=(yields(beg+del:T,1)-yields(beg:beg+Ts-1,1))*100;

result_4_noc = ols (dy4,xy4_noc);
result_4_nod = ols (dy4,xy4_nod);
result_4_fama = ols (dy4,xy4_fama);
result_4_cp = ols (dy4,xy4_cp);
result_4_my = ols (dy4,xy4_my);
result_4_all = ols (dy4,xy4_all);

% print resutl
disp ('x=4')
disp ('no cycle')
disp ([result_4_noc.beta result_4_noc.bstd])
disp (result_4_noc.rbar)

disp ('no dymmy')
disp ([result_4_nod.beta result_4_nod.bstd])
disp (result_4_nod.rbar)

disp ('Fama cycle')
disp ([result_4_fama.beta result_4_fama.bstd])
disp (result_4_fama.rbar)

disp ('CP cycle')
disp ([result_4_cp.beta result_4_cp.bstd])
disp (result_4_cp.rbar)

disp ('my cycle')
disp ([result_4_my.beta result_4_my.bstd])
disp (result_4_my.rbar)

disp ('all')
disp ([result_4_all.beta result_4_all.bstd])
disp (result_4_all.rbar)
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%Five-year change in spot rate
del=20;
Ts   = T-beg-del+1;
xy5_noc=[ones(Ts,1) dum(beg:T-del) 100*fs(beg:beg+Ts-1,2)];
xy5_nod=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100];
xy5_fama=[ones(Ts,1) dum(beg:T-del) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100];
xy5_my=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) yields(beg:beg+Ts-1,1)*100 -my_ma(1:Ts,1)*100];
% xy5_cp=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) yields(beg:beg+Ts-1,1)*100 tao_r(1:1+Ts-1,1)*100];
xy5_cp=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-tao_r(1:1+Ts-1,1))*100];
xy5_all=[ones(Ts,1) 100*fs(beg:beg+Ts-1,2) (yields(beg:beg+Ts-1,1)-K_t(beg:beg+Ts-1,1))*100 (yields(beg:beg+Ts-1,1)-tao_r(1:1+Ts-1,1))*100 yields(beg:beg+Ts-1,1)*100-my_ma(1:Ts,1)*100 ];
dy5=(yields(beg+del:T,1)-yields(beg:beg+Ts-1,1))*100;

result_5_noc = ols (dy5,xy5_noc);
result_5_nod = ols (dy5,xy5_nod);
result_5_fama = ols (dy5,xy5_fama);
result_5_cp = ols (dy5,xy5_cp);
result_5_my = ols (dy5,xy5_my);
result_5_all = ols (dy5,xy5_all);

% print resutl
disp ('x=5')
disp ('no cycle')
disp ([result_5_noc.beta result_5_noc.bstd])
disp (result_5_noc.rbar)

disp ('no dymmy')
disp ([result_5_nod.beta result_5_nod.bstd])
disp (result_5_nod.rbar)

disp ('Fama cycle')
disp ([result_5_fama.beta result_5_fama.bstd])
disp (result_5_fama.rbar)

disp ('CP cycle')
disp ([result_5_cp.beta result_5_cp.bstd])
disp (result_5_cp.rbar)

disp ('my cycle')
disp ([result_5_my.beta result_5_my.bstd])
disp (result_5_my.rbar)

disp ('all')
disp ([result_5_all.beta result_5_all.bstd])
disp (result_5_all.rbar)
%--------------------------------------------------------------------------
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Out of sample forecasts comparison
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%--------------------------------------------------------------------------
% % x=2, 2-year ahead
% del=8;
% Ts   = T-beg-del+1;
% x2_fama=[ones(Ts,1) yields(beg:beg+Ts-1,1) K_t(beg:beg+Ts-1,1) dum(beg:T-del)];
% x2_cp=[ones(Ts,1) yields(beg:beg+Ts-1,1) tao_r(1:1+Ts-1,1)];
% x2_my=[ones(Ts,1) yields(beg:beg+Ts-1,1) my_ma(1:Ts,1)];
% dy2=(yields(beg+del:T,1)-yields(beg:beg+Ts-1,1));
% 
% result2_fama =ols(dy2,x2_fama); % HH
% result2_cp =ols(dy2,x2_cp); % HH
% result2_my =ols(dy2,x2_my); % HH
% 
% cycle2_fama = result2_fama.yhat;
% cycle2_cp = result2_cp.yhat;
% cycle2_my = result2_my.yhat;
% 
% x2_mf = [ones(Ts,1) cycle2_my cycle2_fama];
% x2_mcp = [ones(Ts,1) cycle2_my cycle2_cp];
% result2_mf =ols(dy2,x2_mf); % HH
% result2_mcp =ols(dy2,x2_mcp); % HH
% 
% % x=3, 3-year ahead
% del=12;
% Ts   = T-beg-del+1;
% x3_fama=[ones(Ts,1) yields(beg:beg+Ts-1,1) K_t(beg:beg+Ts-1,1) dum(beg:T-del)];
% x3_cp=[ones(Ts,1) yields(beg:beg+Ts-1,1) tao_r(1:1+Ts-1,1)];
% x3_my=[ones(Ts,1) yields(beg:beg+Ts-1,1) my_ma(1:Ts,1)];
% dy3=(yields(beg+del:T,1)-yields(beg:beg+Ts-1,1));
% 
% result3_fama =ols(dy3,x3_fama); % HH
% result3_cp =ols(dy3,x3_cp); % HH
% result3_my =ols(dy3,x3_my); % HH
% 
% cycle3_fama = result3_fama.yhat;
% cycle3_cp = result3_cp.yhat;
% cycle3_my = result3_my.yhat;
% 
% x3_mf = [ones(Ts,1) cycle3_my cycle3_fama];
% x3_mcp = [ones(Ts,1) cycle3_my cycle3_cp];
% result3_mf =ols(dy3,x3_mf); % HH
% result3_mcp =ols(dy3,x3_mcp); % HH
% 
% % x=4, 4-year ahead
% del=16;
% Ts   = T-beg-del+1;
% x4_fama=[ones(Ts,1) yields(beg:beg+Ts-1,1) K_t(beg:beg+Ts-1,1) dum(beg:T-del)];
% x4_cp=[ones(Ts,1) yields(beg:beg+Ts-1,1) tao_r(1:1+Ts-1,1)];
% x4_my=[ones(Ts,1) yields(beg:beg+Ts-1,1) my_ma(1:Ts,1)];
% dy4=(yields(beg+del:T,1)-yields(beg:beg+Ts-1,1));
% 
% result4_fama =ols(dy4,x4_fama); % HH
% result4_cp =ols(dy4,x4_cp); % HH
% result4_my =ols(dy4,x4_my); % HH
% 
% cycle4_fama = result4_fama.yhat;
% cycle4_cp = result4_cp.yhat;
% cycle4_my = result4_my.yhat;
% 
% x4_mf = [ones(Ts,1) cycle4_my cycle4_fama];
% x4_mcp = [ones(Ts,1) cycle4_my cycle4_cp];
% result4_mf =ols(dy4,x4_mf); % HH
% result4_mcp =ols(dy4,x4_mcp); % HH
% 
% % x=5, 5-year ahead
% del=20;
% Ts   = T-beg-del+1;
% x5_fama=[ones(Ts,1) yields(beg:beg+Ts-1,1) K_t(beg:beg+Ts-1,1) dum(beg:T-del)];
% x5_cp=[ones(Ts,1) yields(beg:beg+Ts-1,1) tao_r(1:1+Ts-1,1) ];
% x5_my=[ones(Ts,1) yields(beg:beg+Ts-1,1) my_ma(1:Ts,1)];
% dy5=(yields(beg+del:T,1)-yields(beg:beg+Ts-1,1));
% 
% result5_fama =ols(dy5,x5_fama); % HH
% result5_cp =ols(dy5,x5_cp); % HH
% result5_my =ols(dy5,x5_my); % HH
% 
% cycle5_fama = result5_fama.yhat;
% cycle5_cp = result5_cp.yhat;
% cycle5_my = result5_my.yhat;
% 
% x5_mf = [ones(Ts,1) cycle5_my cycle5_fama];
% x5_mcp = [ones(Ts,1) cycle5_my cycle5_cp];
% result5_mf =ols(dy5,x5_mf); % HH
% result5_mcp =ols(dy5,x5_mcp); % HH
% 
% % print the results
% disp ('**Resutls of Table 2**')
% disp ('x=2')
% disp ('///beta_myf///std_myf///beta_mycp///std_mycp///')
% disp([result2_mf.beta result2_mf.bstd result2_mcp.beta result2_mcp.bstd])
% disp ('x=3')
% disp ('///beta_myf///std_myf///beta_mycp///std_mycp///')
% disp([result3_mf.beta result3_mf.bstd result3_mcp.beta result3_mcp.bstd])
% disp ('x=4')
% disp ('///beta_myf///std_myf///beta_mycp///std_mycp///')
% disp([result4_mf.beta result4_mf.bstd result4_mcp.beta result4_mcp.bstd])
% disp ('x=5')
% disp ('///beta_myf///std_myf///beta_mycp///std_mycp///')
% disp([result5_mf.beta result5_mf.bstd result5_mcp.beta result5_mcp.bstd])

%% plot: Nominal v.s. Real
load Yields_Real.mat

figure(1)
plot(Time, yields*100,'LineWidth',2.5); hold on
area([2008.75 2014.2], [16.5 16.5]);hold on
plot(Time, yields*100,'LineWidth',2.5); hold on
% plot(2008.75,-2:0.2:20,':k')
ylim=[0 16]; xlim=[1961,2015];
legend('3-month Tbill nominal yield','1-year bond nominal yield','2-year bond nominal yield','3-year bond nominal yield',...
             '4-year bond nominal yield','5-year bond nominal yield')
         
figure(2)
plot(Time, yields_real,'LineWidth',2.5); hold on
area([2008.75 2014.2], [15 15]);hold on
area([2008.75 2014.2], [-5 -5]);hold on
plot(Time, yields_real,'LineWidth',2.5); hold on
% plot(2008.75,-2:0.2:20,':k')
ylim=[-2 14]; xlim=[1961,2015];
legend('3-month Tbill real yield','1-year bond real yield','2-year bond real yield','3-year bond real yield',...
             '4-year bond real yield','5-year bond real yield')
         
figure(3)
LHS = [K_t(21:end) tao_r(21:end) yields(21:end,2)]*100;
[AX,H1,H2] = plotyy(Time(21:end), LHS,Time(21:end), ones(size(yields(21:end),1),1)./my_r(21:end)); hold on
set(AX(1),'YLim',[0 16.5])
set(AX(2),'YLim',[0.8 2.2])
set(H1,'LineWidth',2)
set(H2,'LineWidth',3)
set(H2,'Color','k')
set(AX,'xlim',[1966,2014]);
legend('Fama trend (5-year MA of 1-year bond yield)','10year discounted MA CPI','1-year bond yield','MY (inverted, right-scaled)')
h = area([2008.75 2014.5], [17 17]);hold on
[AX,H1,H2] = plotyy(Time(21:end), LHS,Time(21:end), ones(size(yields(21:end),1),1)./my_r(21:end)); hold on
set(AX(1),'YLim',[0 16.5])
set(AX(2),'YLim',[0.8 2.2])
set(H1,'LineWidth',2)
set(H2,'LineWidth',3)
set(H2,'Color','k')
set(AX,'xlim',[1966,2014]);
% legend('Fama trend (5-year MA of 1-year bond yield)','10year discounted MA CPI','1-year bond yield','MY (inverted, right-scaled)')
% h = area([2008.75 2014.5], [17 17]);hold on
% set(h, 'FaceAlpha',0)
% [AX,H1,H2] = plotyy(Time(21:end), LHS,Time(21:end), ones(size(yields(21:end),1),1)./my_r(21:end)); 
% set(AX(1),'YLim',[0 16.5])
% set(AX(2),'YLim',[0.8 2.2])
% set(H1,'LineWidth',2)
% set(H2,'LineWidth',3)
% set(H2,'Color','k')
% set(AX,'xlim',[1966,2014]);


figure(4)
LHS = [K_t(21:end) tao_r(21:end) yields_real(21:end,2)/100]*100;
[AX,H1,H2] = plotyy(Time(21:end), LHS,Time(21:end), ones(size(yields_real(21:end),1),1)./my_r(21:end)); hold on
set(AX(1),'YLim',[-2.5 12.5])
set(AX(2),'YLim',[0.8 2.2])
set(H1,'LineWidth',2)
set(H2,'LineWidth',3)
set(H2,'Color','k')
set(AX,'xlim',[1966,2014]);
legend('Fama trend (5-year MA of 1-year bond yield)','10 year discounted MA CPI','1-year bond real yield','MY (inverted, right-scaled)')
h1 = area([2008.75 2014.5], [17 17]);hold on
h2 = area([2008.75 2014.5], [-17 -17]);hold on
[AX,H1,H2] = plotyy(Time(21:end), LHS,Time(21:end), ones(size(yields_real(21:end),1),1)./my_r(21:end)); hold on
set(AX(1),'YLim',[-2.5 12.5])
set(AX(2),'YLim',[0.8 2.2])
set(H1,'LineWidth',2)
set(H2,'LineWidth',3)
set(H2,'Color','k')
set(AX,'xlim',[1966,2014]);
% legend('Fama trend (5-year MA of 1-year bond yield)','10year discounted MA CPI','1-year bond yield','MY (inverted, right-scaled)')
% h = area([2008.75 2014.5], [17 17]);hold on
% set(h, 'FaceAlpha',0)
% [AX,H1,H2] = plotyy(Time(21:end), LHS,Time(21:end), ones(size(yields(21:end),1),1)./my_r(21:end)); 
% set(AX(1),'YLim',[0 16.5])
% set(AX(2),'YLim',[0.8 2.2])
% set(H1,'LineWidth',2)
% set(H2,'LineWidth',3)
% set(H2,'Color','k')
% set(AX,'xlim',[1966,2014]);

